@@ -1,7 +1,13 @@
 import os
 
 BATCH_SIZE = int(os.getenv("BATCH_SIZE", "0"))
-TIMEOUT = float(os.getenv("TIMEOUT", "0"))
+MESSAGING_TIMEOUT = float(os.getenv("MESSAGING_TIMEOUT", "0"))
+PROCESSING_TIMEOUT = (
+    float(os.environ["PROCESSING_TIMEOUT"]) if "PROCESSING_TIMEOUT" in os.environ else None
+)
+RESENDS = int(os.getenv("RESENDS", "0"))
+RETRIES = int(os.getenv("RETRIES", "0"))
+SLEEP_TIME = float(os.getenv("SLEEP_TIME", "0"))
 
 KAFKA_BOOTSTRAP_SERVERS = os.getenv("KAFKA_BOOTSTRAP_SERVERS", "localhost:9092")
 NATS_SERVERS = os.getenv("NATS_SERVERS", "nats://localhost:4222")
