@@ -1,4 +1,5 @@
 import abc
+from datetime import datetime
 from typing import Any, Dict
 from uuid import UUID
 
@@ -9,6 +10,8 @@ class SerializerABC(abc.ABC):
         if "__type__" in obj:
             if obj["__type__"] == "uuid.UUID":
                 obj = UUID(obj["__value__"])
+            elif obj["__type__"] == "datetime.datetime":
+                obj = datetime.fromisoformat(obj["__value__"])
             elif obj["__type__"] == "bytes":
                 obj = obj["__value__"].encode()
         return obj
@@ -18,6 +21,9 @@ class SerializerABC(abc.ABC):
         if isinstance(obj, UUID):
             obj = {"__type__": "uuid.UUID", "__value__": str(obj)}
             return obj
+        elif isinstance(obj, datetime):
+            obj = {"__type__": "datetime.datetime", "__value__": obj.isoformat()}
+            return obj
         elif isinstance(obj, bytes):
             obj = {"__type__": "bytes", "__value__": obj.decode()}
             return obj
